@@ -59,13 +59,12 @@ def safe_div(x: tf.Tensor,y: tf.Tensor, eps:tf.Tensor = tf.constant(1e-6)):
 
     Returns
     -------
-    x/(y+eps) : tf.Tensor
+    sign(y) * x/(|y|+eps) : tf.Tensor
         Results
 
     Notes
     -----
-    User must guaruantee the following conditions
-    eps >= 0
+    User must guaruantee `eps >= 0`
     """
     _eps = tf.cast(eps,dtype=y.dtype)
     return x/(tf.where(y >= 0, y + _eps, y - _eps))
@@ -82,6 +81,11 @@ def safe_exp(x: tf.Tensor, BIG: tf.Tensor = tf.constant(20)):
         Input
     BIG : tf.Tensor, optional
         Maximum exponent. The default value is 20 (exp(x) <= 1e+20).
+
+    Returns
+    -------
+    exp(min(x,BIG)) : tf.Tensor
+        Results
     """
     return tf.math.exp(tf.math.minimum(x,tf.cast(BIG,dtype=x.dtype)))
 
@@ -119,7 +123,7 @@ def create_model(units,cls=tfp.layers.DenseReparameterization,
 
 
 def multivariate_normal_fn(loc,relative=0.01):
-    """
+    r"""
     Create a function for multivariate normal N(loc, abs(loc)*relative)
 
     This function can be used like `tfp.layers.util.default_multivariate_normal_fn`
@@ -129,7 +133,7 @@ def multivariate_normal_fn(loc,relative=0.01):
     loc : array-like
         Mean for normal function
     relative : float
-        Standard deviation = |loc * relative|
+        Standard deviation = abs(loc * relative)
 
     Returns
     -------
